package org.zerock.controller;

import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import org.zerock.domain.Criteria;
import org.zerock.domain.ReplyPageDTO;
import org.zerock.domain.ReplyVO;
import org.zerock.service.ReplyService;

import lombok.AllArgsConstructor;
import lombok.extern.log4j.Log4j;

@RequestMapping("/replies")
@RestController
@Log4j
@AllArgsConstructor
public class ReplyController {
	private ReplyService service;
	
	
	//목록
	@GetMapping(value="/pages/{bno}/{page}",
			produces= {MediaType.APPLICATION_RSS_XML_VALUE,
					   MediaType.APPLICATION_JSON_UTF8_VALUE	
						})
	public ResponseEntity<ReplyPageDTO> getList(@PathVariable("page") int page,
												@PathVariable("bno") Long bno){
		Criteria cri=new Criteria(page,10);
		
		return new ResponseEntity<>(service.getListPage(cri, bno),HttpStatus.OK);
		
	}
	
	//한건검색.상세보기
	@GetMapping(value="/{rno}",
			produces= {MediaType.APPLICATION_RSS_XML_VALUE,
					   MediaType.APPLICATION_JSON_UTF8_VALUE	
						})
	public ResponseEntity<ReplyVO> get(@PathVariable("rno") Long rno){
	
	
	return new ResponseEntity<>(service.get(rno),HttpStatus.OK);
	
	}
	
	//삭제
	@DeleteMapping(value="/{rno}",produces= {MediaType.TEXT_PLAIN_VALUE})
	public ResponseEntity<String> remove(@PathVariable("rno") Long rno){
		return service.remove(rno)==1?new ResponseEntity<>("success",HttpStatus.OK):new ResponseEntity<>(HttpStatus.INTERNAL_SERVER_ERROR);
	}
	//수정
	@RequestMapping(method= {RequestMethod.PUT,RequestMethod.PATCH},
					value="/{rno}",consumes="application/json",
					produces= {MediaType.TEXT_PLAIN_VALUE})
	public ResponseEntity<String> modify(@RequestBody ReplyVO vo,
										@PathVariable("rno") Long rno){
		vo.setRno(rno);
		
		return service.modify(vo)==1?new ResponseEntity<>("success",HttpStatus.OK):new ResponseEntity<>(HttpStatus.INTERNAL_SERVER_ERROR);
	}
	//등록
	@PostMapping(value="/new",consumes="application/json",
			produces= {MediaType.TEXT_PLAIN_VALUE})
	public ResponseEntity<String> create(@RequestBody ReplyVO vo){
		int insertCount=service.register(vo);
		
		return insertCount==1?new ResponseEntity<>("success",HttpStatus.OK):new ResponseEntity<>(HttpStatus.INTERNAL_SERVER_ERROR);
	}
	
	
}
